package com.ruoyi.post.frequency.posttype.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.post.frequency.posttype.entity.PostType;

import java.util.List;

/**
 * 帖子分类Mapper接口
 * 
 * @author liwenlong
 * @date 2023-10-10
 */
public interface PostTypeMapper  extends BaseMapper<PostType>
{
    /**
     * 查询帖子分类
     * 
     * @param id 帖子分类主键
     * @return 帖子分类
     */
    public PostType selectPostTypeById(Long id);

    /**
     * 查询帖子分类列表
     * 
     * @param postType 帖子分类
     * @return 帖子分类集合
     */
    public List<PostType> selectPostTypeList(PostType postType);

    /**
     * 新增帖子分类
     * 
     * @param postType 帖子分类
     * @return 结果
     */
    public int insertPostType(PostType postType);

    /**
     * 修改帖子分类
     * 
     * @param postType 帖子分类
     * @return 结果
     */
    public int updatePostType(PostType postType);

    /**
     * 删除帖子分类
     * 
     * @param id 帖子分类主键
     * @return 结果
     */
    public int deletePostTypeById(Long id);

    /**
     * 批量删除帖子分类
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostTypeByIds(Long[] ids);
}
